pyxmpp2.mainloop.interfaces.PrepareAgain

Package pyxmpp2 :: Package mainloop :: Module interfaces :: Class PrepareAgain |
[hide private]

# Class PrepareAgain

Returned by the IOHandler.prepare method when the method needs to be called again.

Instance Methods | [hide private]
__init__(self, timeout=None) x.__init__(...) initializes x; see help(type(x)) for signature |
__repr__(self) repr(x) |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Instance Variables | [hide private]
| timeout how long may the main loop wait before calling IOHandler.prepare again.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, timeout=None) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)